@@ -7,6 +7,7 @@ import argparse
 import inspect
 import os
 import pprint
+import shutil
 import sys
 from pathlib import Path
 
@@ -20,40 +21,47 @@ try:
 except ImportError:
     colorama_init = None
 
-    class Fore:
+    class Fore:                # noqa: PIE795
         CYAN = "\x1b[1;96m"
         GREEN = "\x1b[1;92m"
         YELLOW = "\x1b[1;93m"
 
-    class Style:
+    class Style:               # noqa: PIE795
         BRIGHT = "\x1b[1m"
         RESET_ALL = "\x1b[0m"
 
 
-TOX_ENV_NAME = os.environ.get("TOX_ENV_NAME", None)
+DUMP_DIR = "_dump"
+TOX_ENV_NAME = os.environ.get("TOX_ENV_NAME")
 
+# These dirs will be processed if exists, so no need to remove old entries.
+# I suggest keeping them to clean up old artefacts just in case.
 WORKDIRS = (
     ".mypy_cache",
     ".pytype",
-    ".pytest-cache",
-    ".pytest_cache",
+    ".pytest-cache",  # <-+-- One of these is a typo
+    ".pytest_cache",  # <-+   Keep them both just in case
     ".tox",
-    "_dynamic",
+    DUMP_DIR,
+    "_dynamic",  # Pre 1.4.0a4
     "aiosmtpd.egg-info",
     "build",
     "dist",
     "htmlcov",
-    "prof",
+    "prof",  # Only if "profile" testenv ran
 )
 
 WORKFILES = (
     ".coverage",
+    ".coverage.*",
     "coverage.xml",
     "diffcov.html",
     "coverage-*.xml",
     "diffcov-*.html",
 )
 
+TERM_WIDTH, TERM_HEIGHT = shutil.get_terminal_size()
+
 
 # region #### Helper funcs ############################################################
 
@@ -61,7 +69,8 @@ WORKFILES = (
 def deldir(targ: Path, verbose: bool = True):
     if not targ.exists():
         return
-    for i, pp in enumerate(reversed(sorted(targ.rglob("*"))), start=1):
+    rev_items = sorted(targ.rglob("*"), reverse=True)
+    for i, pp in enumerate(rev_items, start=1):
         if pp.is_symlink():
             pp.unlink()
         elif pp.is_file():
@@ -72,7 +81,7 @@ def deldir(targ: Path, verbose: bool = True):
             pp.rmdir()
         else:
             raise RuntimeError(f"Don't know how to handle '{pp}'")
-        if verbose and (i & 0x1FF) == 0:
+        if verbose and ((i & 0x3FF) == 0):
             print(".", end="", flush=True)
     targ.rmdir()
 
@@ -84,12 +93,14 @@ def deldir(targ: Path, verbose: bool = True):
 
 
 def dump_env():
-    os.makedirs("_dynamic", exist_ok=True)
-    with open(f"_dynamic/ENV.{TOX_ENV_NAME}", "wt") as fout:
+    dumpdir = Path(DUMP_DIR)
+    dumpdir.mkdir(exist_ok=True)
+    with (dumpdir / f"ENV.{TOX_ENV_NAME}.py").open("wt") as fout:
+        print("ENV = \\", file=fout)
         pprint.pprint(dict(os.environ), stream=fout)
 
 
-def move_prof():
+def move_prof(verbose: bool = False):
     """Move profiling files to per-testenv dirs"""
     profpath = Path("prof")
     # fmt: off
@@ -102,43 +113,49 @@ def move_prof():
     if not prof_files:
         return
     targpath = profpath / TOX_ENV_NAME
+    if verbose:
+        print(f"Gathering to {targpath} ...", end="", flush=True)
     os.makedirs(targpath, exist_ok=True)
     for f in targpath.glob("*"):
         f.unlink()
     for f in prof_files:
+        if verbose:
+            print(".", end="", flush=True)
         f.rename(targpath / f.name)
+    if verbose:
+        print(flush=True)
 
 
 def pycache_clean(verbose=False):
     """Cleanup __pycache__ dirs & bytecode files (if any)"""
     aiosmtpdpath = Path(".")
     for i, f in enumerate(aiosmtpdpath.rglob("*.py[co]"), start=1):
-        if verbose and (i % 0x3FF) == 0:
+        if verbose and ((i & 0xFF) == 0):
             print(".", end="", flush=True)
         f.unlink()
-    for d in aiosmtpdpath.rglob("__pycache__"):
-        if verbose:
+    for i, d in enumerate(aiosmtpdpath.rglob("__pycache__"), start=1):
+        if verbose and ((i & 0x7) == 0):
             print(".", end="", flush=True)
         deldir(d, verbose)
     if verbose:
-        print()
+        print(flush=True)
 
 
 def rm_work():
     """Remove work dirs & files. They are .gitignore'd anyways."""
-    print(f"{Style.BRIGHT}Removing work dirs ... ", end="")
+    print(f"{Style.BRIGHT}Removing work dirs ... ", end="", flush=True)
     # The reason we list WORKDIRS explicitly is because we don't want to accidentally
     # bork IDE workdirs such as .idea/ or .vscode/
     for dd in WORKDIRS:
         print(dd, end="", flush=True)
         deldir(Path(dd))
         print(" ", end="", flush=True)
-    print(f"\n{Style.BRIGHT}Removing work files ...", end="")
+    print(f"\n{Style.BRIGHT}Removing work files ...", end="", flush=True)
     for fnglob in WORKFILES:
         for fp in Path(".").glob(fnglob):
             print(".", end="", flush=True)
             fp.exists() and fp.unlink()
-    print()
+    print(flush=True)
 
 
 # endregion
@@ -205,6 +222,14 @@ def get_opts(argv):
     parser.add_argument(
         "--force", "-F", action="store_true", help="Force action even if in CI"
     )
+    parser.add_argument(
+        "-A",
+        "--afterbar",
+        dest="afterbar",
+        default=0,
+        action="count",
+        help="Print horizontal bar after action. Repeat this option for more bars.",
+    )
 
     # From: https://stackoverflow.com/a/49999185/149900
     parser.add_argument(
@@ -218,7 +243,7 @@ def get_opts(argv):
 
 
 def python_interp_details():
-    print(f"{Fore.CYAN}Python interpreter details:")
+    print(f"{Fore.CYAN}\u259E\u259E\u259E Python interpreter details:")
     details = sys.version.splitlines() + sys.executable.splitlines()
     for ln in details:
         print(f"    {Fore.CYAN}{ln}")
@@ -240,8 +265,14 @@ if __name__ == "__main__":
             sys.exit(0)
         else:
             print(f"{Fore.YELLOW}We're in CI but --force is specified")
-    print(f"{Fore.GREEN}{Path(__file__).name} {opts.cmd}{Style.RESET_ALL}")
+    print(
+        f"{Fore.GREEN}>>> "
+        f"{Path(__file__).name} {opts.cmd}{Style.RESET_ALL}",
+        flush=True,
+    )
     dispatcher = globals().get(f"dispatch_{opts.cmd}")
     dispatcher()
+    for _ in range(opts.afterbar):
+        print(Fore.CYAN + ("\u2550" * (TERM_WIDTH - 1)))
     # Defensive reset
     print(Style.RESET_ALL, end="", flush=True)
